@@ -33,7 +33,7 @@ coef.ncvreg <- function(object, lambda, which=1:length(object$lambda), drop=TRUE
     r <- ceiling(ind)
     w <- ind %% 1
     beta <- (1-w)*object$beta[,l,drop=FALSE] + w*object$beta[,r,drop=FALSE]
-    colnames(beta) <- round(lambda,4)
+    colnames(beta) <- lamNames(lambda)
   }
   else beta <- object$beta[, which, drop=FALSE]
   if (drop) return(drop(beta)) else return(beta)
