@@ -44,6 +44,7 @@ SEXP cdfit_cox_dh(SEXP X_, SEXP d_, SEXP penalty_, SEXP lambda, SEXP eps_, SEXP
   double *lam = REAL(lambda);
   double eps = REAL(eps_)[0];
   int max_iter = INTEGER(max_iter_)[0];
+  int tot_iter = 0;
   double gamma = REAL(gamma_)[0];
   double *m = REAL(multiplier);
   double alpha = REAL(alpha_)[0];
@@ -100,16 +101,17 @@ SEXP cdfit_cox_dh(SEXP X_, SEXP d_, SEXP penalty_, SEXP lambda, SEXP eps_, SEXP
       for (int j=0; j<p; j++) {
         if (a[j] != 0) nv++;
       }
-      if (nv > dfmax) {
+      if ((nv > dfmax) | (tot_iter == max_iter)) {
         for (int ll=l; ll<L; ll++) INTEGER(iter)[ll] = NA_INTEGER;
         res = cleanupCox(a, e, eta, haz, rsk, beta, Loss, iter, Eta);
         return(res);
       }
     }
 
-    while (INTEGER(iter)[l] < max_iter) {
-      while (INTEGER(iter)[l] < max_iter) {
+    while (tot_iter < max_iter) {
+      while (tot_iter < max_iter) {
         INTEGER(iter)[l]++;
+        tot_iter++;
         REAL(Loss)[l] = 0;
         double maxChange = 0;
 
@@ -168,7 +170,7 @@ SEXP cdfit_cox_dh(SEXP X_, SEXP d_, SEXP penalty_, SEXP lambda, SEXP eps_, SEXP
                 r[i] -= si;
                 eta[i] += si;
               }
-              if (fabs(shift)*v > maxChange) maxChange = fabs(shift)*v;
+              if (fabs(shift)*sqrt(v) > maxChange) maxChange = fabs(shift)*sqrt(v);
             }
           }
         }
